@@ -28,7 +28,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.30';
+our $VERSION = '2.31';
 
 =head1 SYNOPSIS
 
@@ -266,7 +266,6 @@ EOF
     },
 );
 
-#This is redundant already in Runner::Init
 #=head2 procs_per_sbatch
 #
 #Number of processes to use per sbatch. By default this is a conservative number as there is no checking mechanism to see how 'heavy' a job is.
@@ -276,7 +275,7 @@ EOF
 #has procs_per_sbatch => (
 #    is => 'rw',
 #    isa => 'Int',
-#    default => 3,
+#    default => 4,
 #    required => 0,
 #);
 
@@ -548,9 +547,6 @@ sub run {
     if($self->serial){
         $self->procs(1);
     }
-    else{
-        $self->procs(4);
-    }
 
     $self->check_files;
     $self->parse_file_slurm;
